% Script loads corrected_variables_vd, and finds trajectory when supply is
% linearily tracked relative input signal voltage.
clear all;
close all;


load corrected_variables_vd;
[dummy idx_12] = min((corrected_gain_vd(13,:)-12).^2); %power idx at 12 db gain
[dummy idx_10] = min((corrected_gain_vd(13,:)-10).^2); %power idx at 10 db gain

% po_at_12dbg = corrected_pout_vd(13,idx_12); %power at idx that gives 12db gain
% po_at_10dbg = corrected_pout_vd(13,idx_10); %power at idx that gives 10db gain

pi_at_12dbg = corrected_pout_vd(13,idx_12)-corrected_gain_vd(13,idx_12); %input power at idx that gives 12db gain
pi_at_10dbg = corrected_pout_vd(13,idx_10)-corrected_gain_vd(13,idx_10); %input power at idx that gives 10db gain

% vo_at_12dbg = sqrt(50.*10.^((po_at_12dbg-30)/10)); %power converted to rf voltage
% vo_at_10dbg = sqrt(50.*10.^((po_at_10dbg-30)/10)); %power converted to rf voltage

vi_at_12dbg = sqrt(50.*10.^((pi_at_12dbg-30)/10)); %power converted to rf voltage
vi_at_10dbg = sqrt(50.*10.^((pi_at_10dbg-30)/10)); %power converted to rf voltage

%make these points correspond to vd 0->28 v
lin_vd_12dbg = 4:2:28;
lin_vd_10dbg = 4:2:28;

%create evenly distributed points along line to (vo_at_12dbg, 28) and 10dbg
% lin_vo_12dbg = linspace(4,vo_at_12dbg,length(lin_vd_12dbg));
% lin_vo_10dbg = linspace(4,vo_at_10dbg,length(lin_vd_10dbg));

lin_vi_12dbg = linspace(0,vi_at_12dbg,length(lin_vd_12dbg));
lin_vi_10dbg = linspace(0,vi_at_10dbg,length(lin_vd_10dbg));




figure(6)
hold on;
plot([0    10.6796], [0 28])
plot(lin_vi_12dbg,lin_vd_12dbg)
plot(lin_vi_10dbg,lin_vd_10dbg, 'r')

%converting to dbm
lin_pi_12dbg = 10*log10(((lin_vi_12dbg).^2/50)./1e-3);
lin_pi_10dbg = 10*log10(((lin_vi_10dbg).^2/50)./1e-3);

% Plotting supply voltages
% figure(5)
% hold on;
% plot(lin_vo_12dbg,lin_vd_12dbg)
% plot(lin_vo_10dbg,lin_vd_10dbg, 'r')


%converting to dbm
% lin_po_12dbg = 10*log10(((lin_vo_12dbg).^2/50)./1e-3);
% lin_po_10dbg = 10*log10(((lin_vo_10dbg).^2/50)./1e-3);


for i=1:length(lin_vi_12dbg)
    % Mapping 12dbg
    [dummy volt_12] = min((vd_corr-lin_vd_12dbg(i)).^2); %find index in vd_corr(whose values indicate what voltage rows in the corrected files are measured for) that corresponds with vo_at_12dbg(i)
    [dummy pow_12] = min((corrected_pout_vd(volt_12,:)-corrected_gain_vd(volt_12,:)-lin_pi_12dbg(i)).^2); %find index in vd_corr(whose values indicate what voltage rows in the corrected files are measured for) that corresponds with po_at_12dbg(i)
    gain_12(i) = corrected_gain_vd(volt_12,pow_12);
    pae_12(i) = corrected_pae_vd(volt_12,pow_12);
    pout_12(i) = corrected_pout_vd(volt_12,pow_12);
    vo_12 = sqrt(50.*10.^((pout_12-30)/10)); %power converted to rf voltage

    
    % Mapping 10dbg
    [~, volt_10] = min((vd_corr-lin_vd_10dbg(i)).^2);
    [~, pow_10] = min((corrected_pout_vd(volt_10,:)-corrected_gain_vd(volt_10,:)-lin_pi_10dbg(i)).^2);
    gain_10(i) = corrected_gain_vd(volt_10,pow_10);
    pae_10(i) = corrected_pae_vd(volt_10,pow_10);
    pout_10(i) = corrected_pout_vd(volt_10,pow_10);
    vo_10 = sqrt(50.*10.^((pout_10-30)/10));
end



% plotting vd curves
for i=1:length(vd_corr)
    figure(1)
    hold on;
    plot(corrected_pout_vd(i,:), corrected_gain_vd(i,:),'Color',[0.75,0.75,0.75], 'linesmooth', 'on')

    figure(2)
    hold on
     plot(corrected_pout_vd(i,:)-corrected_gain_vd(i,:), corrected_pout_vd(i,:),'Color',[0.75,0.75,0.75], 'linesmooth', 'on')

     figure(3)
    hold on
     plot(corrected_pout_vd(i,:), corrected_pae_vd(i,:),'Color',[0.75,0.75,0.75], 'linesmooth', 'on')    
end

%plotting trajectories at 12dbg and 10dbg
figure(2)
plot(pout_12-gain_12,pout_12, 'linesmooth', 'on')
figure(3)
plot(pout_12,pae_12)
figure(1)
plot(pout_12,gain_12)
vi_12 = sqrt(50.*10.^((pout_12-gain_12-30)/10));
% figure(4)
% plot(vi_12,lin_vd_12dbg);
figure(5)
hold on;
plot(vo_12, lin_vd_12dbg)
plot(vo_10, lin_vd_10dbg, 'r')

figure(2)
plot(pout_10-gain_10,pout_10, 'r')
figure(3)
plot(pout_10,pae_10, 'r')
figure(1)
plot(pout_10,gain_10, 'r')

% vi_10 = sqrt(50.*10.^((pout_10-gain_10-30)/10));
% figure(4)
% hold on;
% plot(vi_10,lin_vd_10dbg, 'r');

%% Printing flat
% figure(3)
% matlab2tikz('track_lin_pae.tikz', 'height', '\figureheight', 'width', '\figurewidth')
% 
% figure(5)
% matlab2tikz('track_lin_vout.tikz', 'height', '\figureheight', 'width', '\figurewidth')
% 
% figure(1)
% matlab2tikz('track_lin_gain.tikz', 'height', '\figureheight', 'width', '\figurewidth')
% 
% figure(6)
% matlab2tikz('track_lin_vin.tikz', 'height', '\figureheight', 'width', '\figurewidth')
% figure(2)
% matlab2tikz('track_lin_pout.tikz', 'height', '\figureheight', 'width', '\figurewidth')